## 0.1.9 (2026-01-31)

[支持 Python 3.13](https://gitee.com/MulanRevive/mulan-rework/issues/IBF1FT)

## 0.1.8.1（2025-2-21）

因 codegen 不再发布于 pypi，将其 [内置](https://gitee.com/MulanRevive/mulan-rework/issues/IBO250)。

## 0.1.6.4（2024-08-16）

发布到 pypi 时，误将版本退回。

[发布版与测试版报错一致化](https://gitee.com/MulanRevive/mulan-rework/issues/I68ED1)

## 0.1.7 (2024-3-30)

支持 Python 3.12

## 0.1.6 (2024-3-27)

支持 Python 3.10 与 3.11

## 0.1.5 (2024-3-24)

支持 Python 3.9

## 0.1.4（2024-2-20）

[解决报错信息与测试用例不符问题](https://gitee.com/MulanRevive/mulan-rework/pulls/65)

## 0.1.3 (2023-1-5)

[基本复现命令行选项](文档/用户手册/命令行参数.md)

## 0.1.0 (2022-12-17)

[今年悬赏任务成果](https://zhuanlan.zhihu.com/p/592786914)

## 0.0.22 (2021-07-18)

[继续 py 转木兰；探路 py 3.8](https://zhuanlan.zhihu.com/p/391093875)

## 0.0.21 (2021-07-10)

[查缺补漏；rply 改进、接口中文化](https://zhuanlan.zhihu.com/p/388440048)

## 0.0.20 (2021-06-20)

改用 rply-ulang 中文 API

## 0.0.19（2021-05-30）

[补完二元运算；重现 yield 语法；赋值时可指定变量类型](https://zhuanlan.zhihu.com/p/376747637)

## 0.0.18（2021-05-18）

[补完所有内置函数，悬赏任务合作顺利](https://zhuanlan.zhihu.com/p/373278659)

## 0.0.17.4（2021-05-13）

[发现依赖库风险、不支持 in；发布 Gitee Reward 首批悬赏任务](https://zhuanlan.zhihu.com/p/372021884)

## 0.0.17.3（2021-05-06）

[支持不需 __init__的 super 调用](https://zhuanlan.zhihu.com/p/370117192)

## 0.0.17.2（2021-05-02）

[实现简易网页浏览器，又一次碰到语法歧义](https://zhuanlan.zhihu.com/p/369268306)

## 0.0.17.1（2021-04-20）

python 代码转换为木兰：
- 单参数、多参数、带默认值参数函数定义
- 类、类方法、构造方法、嵌套类、扩展类
- 引用属性、类方法
- 不过：
  - 变长指名参数
  - 属性方法

添加命令行选项：语法树


## 0.0.17（2021-04-02）

着手由 Python 语法树生成木兰源码

## 0.0.16.2（2021-03-01）

报错信息改进：尝试解析错误所在行

## 0.0.16.1（2021-02-16）

测试，文档更新

## 0.0.16（2021-01-17）

[添加 try...catch；内置 min](https://zhuanlan.zhihu.com/p/345139002)

## 0.0.15.1（2020-12-10）

语法: 抛出（throw）; 内置函数: isa; 报错：属性错误信息修正

## 0.0.15.0 （2020-11-18）

[基于网络的运行环境；词法错误处理](https://zhuanlan.zhihu.com/p/301086221)

## 0.0.14.8 (2020-11-07)

[websocket 聊天演示；部分比较 Python 语法](https://zhuanlan.zhihu.com/p/277557485)

## 0.0.14.7 (2020-11-01)

[功能覆盖初版用户手册；Gitee Go 流水线尝鲜](https://zhuanlan.zhihu.com/p/271636727)

## 0.0.14.6 （2020-10-25）

[网络服务演示；with...as 的替代语法](https://zhuanlan.zhihu.com/p/268660973)

## 0.0.14.5 （2020-10-22）
修复： windows 下[引用模块问题](https://gitee.com/MulanRevive/mulan-rework/issues/I1U2HP)，现可运行井字棋与编辑器。

## 0.0.14.4 （2020-10-21）
[中文报错信息](https://zhuanlan.zhihu.com/p/267686876)

## 0.0.14.3 （2020-10-17）
[井字棋演示，tuple、枚举等](https://zhuanlan.zhihu.com/p/266428706)

## 0.0.14.1 （2020-10-14）
首次通过 ulang 包发布在 PyPI，[这里详细介绍](https://zhuanlan.zhihu.com/p/265695809)版本号解释、与之前逆向工程的对比等等